@@ -1,3 +1,3 @@
 from questionflow.classes import Question, Answer, MultipleAnswerQuestion, MultipleChoiceQuestion, Choice, \
     YesNoQuestion, YesNoAnswer, YesNo
-from questionflow.question_flow import QuestionFlow
+from questionflow.question_flow import QuestionFlow, ProcessedAnswer
